
Include "data_condo.geo";

Group{
  Domaine = Region[{AIR,DIELECTRIQUE}];
  Dielectrique = Region[{DIELECTRIQUE}];

  Masse = Region[{MASSE}];
  Gamma1 = Region[{DELTAV}];
  Dirichlet = Region[{BORDS}];
}

Function{
  eps[#{AIR}] = eps0;
  eps[#{DIELECTRIQUE}] = eps0*epsr;
  capa_ana = eps0*epsr*2*Pi*h/Log[(Ri+ep+epd)/(Ri+ep)];
  DefineConstant[  
    cana = {capa_ana, Name "Modele/Resultats/0Capa analytique (F)", 
      ReadOnly 1, Highlight "Pink"}
  ];
}


Jacobian{
  { Name Jvol;
    Case {
      { Region All ; Jacobian VolAxi ; }
    }
  }
}

Integration {
  { Name Integ;
    Case { 
      {Type Gauss;
	Case { 
	  { GeoElement Line ; NumberOfPoints 2; }
	  { GeoElement Triangle ; NumberOfPoints 6; } }
      }
    }
  }
}

Constraint {	
  {Name TensionsImposees ;
    Case {      
      { Region Gamma1 ; Type Assign ; Value V1 ; }
      { Region Masse ; Type Assign ; Value 0 ; }
      { Region Dirichlet ; Type Assign ; Value 0 ; }
    }
  }
}

FunctionSpace {
  { Name Hgrad ; Type Form0 ; 
    BasisFunction { 
      { Name sn ; NameOfCoef vn ; Function BF_Node ; 
	Support Region[{Domaine}]  ; Entity NodesOf[All] ; }
    } 
    Constraint {
      { NameOfCoef vn  ; EntityType NodesOf ; 
	NameOfConstraint TensionsImposees ; }
    }
  }
}

Formulation {
  { Name Electrostat ; Type FemEquation ;
    Quantity {
      { Name v  ; Type Local  ; NameOfSpace Hgrad ; }
    }
    Equation {
      Galerkin { [ eps[]*Dof{Grad v}  , {Grad v} ] ;
	In Domaine ; Jacobian Jvol ; Integration Integ ; }
    }
  }
}

Resolution {
  { Name analyse ;
    System {
      { Name Sys ; NameOfFormulation Electrostat ; }
    }
    Operation {
      Generate[Sys] ; 
      Solve[Sys] ;
      SaveSolution[Sys] ;
    }
  }
}

PostProcessing {
  { Name PostProc ; NameOfFormulation Electrostat ;
    Quantity {	
      { Name v  ; Value { Term { [ {v} ] ; 
	    In Domaine ; Jacobian Jvol ; } } }
      { Name e  ; Value { Term { [ -{Grad v} ] ; 
	    In Domaine ; Jacobian Jvol ; } } }
      { Name d  ; Value { Term { [ -eps[]*{Grad v} ] ; 
	    In Domaine ; Jacobian Jvol ; } } }
      { Name nrj ; Value { Integral { [ 2*Pi*eps[]*SquNorm[{Grad v}] ]  ; 
	    In Domaine ; Jacobian Jvol ; Integration Integ ;} } } 
      { Name C ; Value { Integral { [ 4*Pi*eps[]*SquNorm[{Grad v}]/(V1^2) ]  ;
	    In Domaine ; Jacobian Jvol ; Integration Integ ;} } } 
      { Name Q ; Value { Integral { [ 4*Pi*eps[]*SquNorm[{Grad v}]/V1 ]  ;
	    In Domaine ; Jacobian Jvol ; Integration Integ ;} } } 
    }
  }
}

PostOperation PostOp UsingPost PostProc {
  Print[ v, OnElementsOf Domaine, File "v.pos"] ;
  Print[ d, OnElementsOf Domaine, File "d.pos"] ;
  Print[ e, OnElementsOf Domaine, File "e.pos"] ;
  Print[ nrj[Domaine], OnGlobal, File "nrj.dat", 
    SendToServer "Modele/Resultats/1Energie (J)", Color "AliceBlue" ];
  Print[ C[Domaine], OnGlobal, File "capa.dat", 
    SendToServer "Modele/Resultats/2Capa (F)", Color "AliceBlue" ];  
  Print[ Q[Domaine], OnGlobal, File "capa.dat", 
    SendToServer "Modele/Resultats/3Charge (C)", Color "AliceBlue" ];  
}